- [Getting started](https://docs.document360.com/docs/getting-started)
  - [What is Document360?](https://docs.document360.com/docs/document360-getting-started)
  - [Sign up to Document360](https://docs.document360.com/docs/sign-up-to-document-360)
  - [System and browser requirements](https://docs.document360.com/docs/system-and-browser-requirements)
  - [Understanding basic structure](https://docs.document360.com/docs/understanding-basic-structure)
    - [Project dashboard](https://docs.document360.com/docs/document360-my-projects)
    - [Top-right menu overview](https://docs.document360.com/docs/top-right-menu-overview)
    - [Creating a project in Document360](https://docs.document360.com/docs/creating-a-project)
    - [Dashboard](https://docs.document360.com/docs/dashboard)
    - [Workspaces](https://docs.document360.com/docs/workspaces-1)
    - [Multilingual Knowledge bases](https://docs.document360.com/docs/getting-started-with-multi-lingual-knowledge-base)
    - [Creating a sandbox project](https://docs.document360.com/docs/creating-a-sandbox-project)
  - [Security](https://docs.document360.com/docs/security)
    - [Document360 security and infrastructure](https://docs.document360.com/docs/quick-summary-of-the-security-and-infrastructure-aspects)
    - [X-Frame options](https://docs.document360.com/docs/x-frame-options)
    - [Content security policy](https://docs.document360.com/docs/content-security-policy)
    - [CSP and Whitelisting guidelines for Document360 widget](https://docs.document360.com/docs/csp-guidelines-for-document360-widget)
    - [Bot management](https://docs.document360.com/docs/bot-management)
    - [Fair usage policy for bot management](https://docs.document360.com/docs/fair-usage-policy-for-bot-management)
- [Editor choices](https://docs.document360.com/docs/editor)
  - [Editor choices in Document360](https://docs.document360.com/docs/using-the-text-editor)
  - [Elements of the editor](https://docs.document360.com/docs/elements-of-the-editor)
  - [Markdown editor](https://docs.document360.com/docs/markdown-editor-overview)
    - [Basic Markdown syntax](https://docs.document360.com/docs/markdown-basics)
  - [WYSIWYG editor](https://docs.document360.com/docs/wysiwyg-editor)
  - [Advanced WYSIWYG editor](https://docs.document360.com/docs/advanced-wysiwyg-editor-overview)
    - [Advanced WYSIWYG editor](https://docs.document360.com/docs/advanced-wysiwyg-editor)
    - [Advanced WYSIWYG editor basics](https://docs.document360.com/docs/advanced-wysiwyg-editor-basics)
    - [Movable blocks in Advanced WYSIWYG editor](https://docs.document360.com/docs/movable-blocks-in-advanced-wysiwyg-editor)
    - [Conditional content blocks in Advanced WYSIWYG editor](https://docs.document360.com/docs/conditional-content-blocks)
    - [Tables in Advanced WYSIWYG editor](https://docs.document360.com/docs/tables-in-advanced-wysiwyg-editor)
    - [Image formatting in the Advanced WYSIWYG editor](https://docs.document360.com/docs/image-formatting-in-the-advanced-wysiwyg-editor)
    - [Tabs in the Advanced WYSIWYG editor](https://docs.document360.com/docs/tabs-in-the-advanced-wysiwyg-editor)
- [Managing content](https://docs.document360.com/docs/categories-articles)
  - [Categories and subcategories](https://docs.document360.com/docs/categories-and-subcategories)
    - [Managing categories](https://docs.document360.com/docs/managing-categories)
    - [Category types](https://docs.document360.com/docs/category-types)
    - [Mapping a category with a folder in Drive](https://docs.document360.com/docs/assigning-drive-folder-for-a-category)
    - [Downloading category and article in KB site](https://docs.document360.com/docs/downloading-category-and-article-in-kb-site)
  - [Articles](https://docs.document360.com/docs/article)
    - [Managing articles](https://docs.document360.com/docs/managing-articles)
    - [Word .docx files](https://docs.document360.com/docs/article-import-from-word-files)
    - [Publishing an article](https://docs.document360.com/docs/publishing-an-article)
    - [Reviewing an article using Inline comments](https://docs.document360.com/docs/reviewing-an-article-inline-comments)
    - [Adding images to articles](https://docs.document360.com/docs/adding-images-to-articles)
    - [Adding videos in articles](https://docs.document360.com/docs/adding-videos-in-articles)
    - [Adding files to article](https://docs.document360.com/docs/adding-files-to-articles)
    - [Adding hyperlinks](https://docs.document360.com/docs/linking-to-other-articles)
    - [Code blocks](https://docs.document360.com/docs/code-blocks)
    - [Adding private notes](https://docs.document360.com/docs/private-notes)
    - [Embedding Stream videos in articles](https://docs.document360.com/docs/embedding-microsoft-streams-video-in-articles)
    - [Embedding Google forms in articles](https://docs.document360.com/docs/embedding-google-forms-in-article)
    - [Embedding a Draw.io diagram](https://docs.document360.com/docs/embedding-a-drawio-diagram)
  - [All articles](https://docs.document360.com/docs/bulk-operations-overview)
    - [All articles - Overview page](https://docs.document360.com/docs/all-articles-overview-page)
    - [Using filters in All articles page](https://docs.document360.com/docs/filter-bulk-operations)
    - [Export All articles list](https://docs.document360.com/docs/export-bulk-operations)
  - [Article settings](https://docs.document360.com/docs/article-management)
    - [Article review reminder](https://docs.document360.com/docs/review-reminders)
    - [Article SEO](https://docs.document360.com/docs/article-seo)
    - [Excluding articles from search engines](https://docs.document360.com/docs/excluding-articles-from-searches)
    - [Change the URL of an article](https://docs.document360.com/docs/changing-the-url-of-an-article)
    - [Article tags](https://docs.document360.com/docs/article-tags)
    - [Add article labels](https://docs.document360.com/docs/adding-article-labels)
    - [Related articles](https://docs.document360.com/docs/related-articles)
    - [Featured image](https://docs.document360.com/docs/featured-image)
    - [Attachments](https://docs.document360.com/docs/attachments)
    - [Status indicator](https://docs.document360.com/docs/status-indicator)
    - [Article status](https://docs.document360.com/docs/article-status)
    - [Preferences](https://docs.document360.com/docs/preferences)
    - [Show/hide table of contents for an article](https://docs.document360.com/docs/showhide-table-of-contents-for-an-article)
    - [Mark as deprecated](https://docs.document360.com/docs/marking-articles-as-deprecated)
    - [Update article contributors](https://docs.document360.com/docs/updating-article-contributors)
    - [Schedule publishing](https://docs.document360.com/docs/schedule-publishing)
    - [Discussion feed](https://docs.document360.com/docs/article-discussion-feed)
    - [Revision history](https://docs.document360.com/docs/revision-history)
    - [Article analytics](https://docs.document360.com/docs/article-analytics)
    - [Security - Article access control](https://docs.document360.com/docs/article-access-control-knowledge-base-site)
    - [Health check metrics](https://docs.document360.com/docs/health-check-metrics)
    - [Readability score](https://docs.document360.com/docs/readability-score)
    - [Sitemap](https://docs.document360.com/docs/sitemap-generator)
    - [Public article comments](https://docs.document360.com/docs/public-comments)
    - [Robots.txt](https://docs.document360.com/docs/robotstxt)
    - [Read receipt](https://docs.document360.com/docs/read-receipt)
    - [Share articles via private link](https://docs.document360.com/docs/share-articles-via-private-link)
- [AI features](https://docs.document360.com/docs/ai-features)
  - [Eddy AI customization](https://docs.document360.com/docs/ai-customization)
  - [AI machine translation](https://docs.document360.com/docs/ai-machine-translation)
  - [Eddy AI trust page](https://docs.document360.com/docs/eddy-ai-trust-page)
  - [AI writer suite](https://docs.document360.com/docs/ai-writer-suite)
    - [AI writer](https://docs.document360.com/docs/ai-writer)
    - [AI FAQ generator](https://docs.document360.com/docs/ai-faq-generator)
    - [AI title recommender](https://docs.document360.com/docs/ai-title-recommender)
    - [AI SEO description generator](https://docs.document360.com/docs/seo-description-generator)
    - [AI tag recommender](https://docs.document360.com/docs/ai-tag-recommender)
    - [AI related articles recommender](https://docs.document360.com/docs/ai-related-articles-recommender)
    - [AI Chart generator](https://docs.document360.com/docs/ai-chart-generator)
    - [AI alt text generator](https://docs.document360.com/docs/ai-alt-text-generator)
  - [AI search suite](https://docs.document360.com/docs/ai-search-suite)
    - [AI assistive search (Ask Eddy AI)](https://docs.document360.com/docs/ai-assistive-search-ask-eddy)
    - [Eddy AI search analytics](https://docs.document360.com/docs/eddy-search-analytics-1)
    - [AI dynamic related articles recommendation](https://docs.document360.com/docs/ai-dynamic-related-articles-recommendation)
    - [AI Chatbot](https://docs.document360.com/docs/ai-chatbot)
      - [Securing Chatbot authentication using JWT](https://docs.document360.com/docs/securing-chatbot-authentication-using-jwt)
      - [Styling the Chatbot](https://docs.document360.com/docs/styling-the-chatbot)
    - [Adding external sources for AI Assistive search](https://docs.document360.com/docs/eddy-ai-federated-search)
    - [AI article summarizer](https://docs.document360.com/docs/ai-article-summarizer)
    - [Ask Eddy AI API](https://docs.document360.com/docs/ask-eddy-ai-api)
    - [Enhancing accessibility with our read out loud feature](https://docs.document360.com/docs/text-to-voice-functionality)
  - [AI premium suite](https://docs.document360.com/docs/ai-premium-suite)
    - [AI glossary generator](https://docs.document360.com/docs/ai-glossary-generator)
  - AI tips and tricks
    - [How to write GenAI friendly content](https://docs.document360.com/docs/how-to-write-genai-friendly-content)
    - [Prompt engineering tips](https://docs.document360.com/docs/prompt-engineering-tips)
- [File management](https://docs.document360.com/docs/drive)
  - [Adding folders and files](https://docs.document360.com/docs/adding-folders-and-files)
  - [Folder actions in Drive](https://docs.document360.com/docs/folder-actions-in-drive)
  - [File actions in Drive](https://docs.document360.com/docs/file-actions-in-drive)
  - [All files overview](https://docs.document360.com/docs/all-content-overview)
  - [Recent, Starred, and Recycle bin files](https://docs.document360.com/docs/recycle-bin-recent-and-starred-files)
- [Content tools](https://docs.document360.com/docs/content-tools)
  - [Workflows](https://docs.document360.com/docs/workflow)
    - [Workflow designer](https://docs.document360.com/docs/workflow-designer)
    - [Managing workflow status](https://docs.document360.com/docs/managing-workflow-status)
    - [Workflow assignment](https://docs.document360.com/docs/workflow-assignment)
  - [Content reuse](https://docs.document360.com/docs/content-reuse)
    - [Templates](https://docs.document360.com/docs/article-templates)
    - [Variables](https://docs.document360.com/docs/variables)
    - [Snippet](https://docs.document360.com/docs/snippets)
    - [Glossary](https://docs.document360.com/docs/glossary)
      - [Adding glossary terms](https://docs.document360.com/docs/adding-glossary-term)
      - [Inserting glossary term in an article](https://docs.document360.com/docs/adding-glossary-term-in-articles)
      - [Managing glossary terms](https://docs.document360.com/docs/editing-and-deleting-glossary-term)
      - [Managing the glossary landing page](https://docs.document360.com/docs/glossary-overview-page)
  - [Feedback manager](https://docs.document360.com/docs/feedback-manager-overview)
  - [Custom pages](https://docs.document360.com/docs/custom-pages)
  - [Tags](https://docs.document360.com/docs/tags)
    - [Manage tags page overview](https://docs.document360.com/docs/tag-manager-overview-page)
    - [Adding a new tag](https://docs.document360.com/docs/adding-a-new-tag)
    - [Tag groups page overview](https://docs.document360.com/docs/tag-groups-overview)
    - [Manage tag dependencies](https://docs.document360.com/docs/tag-dependency-viewer)
  - [Content essentials](https://docs.document360.com/docs/content-essentials)
    - [Find and replace](https://docs.document360.com/docs/find-and-replace)
    - [SEO descriptions](https://docs.document360.com/docs/seo-descriptions)
  - [Import & Export project/article](https://docs.document360.com/docs/import-export)
    - [Exporting your Document360 project as a ZIP file](https://docs.document360.com/docs/export-documentation-as-zip)
    - [Importing a Document360 project ZIP file](https://docs.document360.com/docs/import-a-documentation-project)
    - [Migrating documentation from other platforms](https://docs.document360.com/docs/migrating-documentation-from-another-knowledge-base-platform)
  - [Export to PDF](https://docs.document360.com/docs/export-to-pdf)
    - [Designing a PDF template](https://docs.document360.com/docs/pdf-design-templates)
    - [Compiling content for PDF](https://docs.document360.com/docs/compliling-content-for-pdf)
- [Analytics](https://docs.document360.com/docs/analytics)
  - [Articles analytics](https://docs.document360.com/docs/articles-analytics)
  - [Eddy AI search analytics](https://docs.document360.com/docs/eddy-ai-search-analytics)
  - [Search analytics](https://docs.document360.com/docs/analytics-search)
  - [Reader analytics](https://docs.document360.com/docs/reader-analytics)
  - [Team accounts analytics](https://docs.document360.com/docs/analytics-team-accounts)
  - [Feedback analytics](https://docs.document360.com/docs/feedback)
  - [Links status analytics](https://docs.document360.com/docs/links-status)
  - [Page not found analytics](https://docs.document360.com/docs/page-not-found-analytics)
  - [Ticket deflector analytics](https://docs.document360.com/docs/ticket-deflector-overview)
- [API Documentation](https://docs.document360.com/docs/api-documentation-tool)
  - [Getting started with API documentation](https://docs.document360.com/docs/api-documentation-getting-started)
  - [Managing API documentation](https://docs.document360.com/docs/manage-api-documentation)
- [Knowledge base widget](https://docs.document360.com/docs/knowledge-base-widget)
  - [Knowledge base widget - Getting started](https://docs.document360.com/docs/knowledge-base-widget-getting-started)
  - [Installing the Knowledge base widget](https://docs.document360.com/docs/installing-the-knowledge-base-widget)
  - [Edit, Clone, and Delete widget](https://docs.document360.com/docs/edit-clone-and-delete)
  - [Managing and customizing the Knowledge base widget](https://docs.document360.com/docs/managing-and-customizing-the-knowledge-base-widget)
  - [URL Mapping](https://docs.document360.com/docs/url-mapping)
  - [Customizing the Knowledge base widget using Custom CSS/JavaScript](https://docs.document360.com/docs/customizing-the-kb-widget-using-custom-css-javascript)
  - [FAQ - Knowledge base widget](https://docs.document360.com/docs/faq-knowledge-base-widget)
- [Knowledge base site](https://docs.document360.com/docs/design-and-styling-knowledge-base-site)
  - [Knowledge base site 2.0](https://docs.document360.com/docs/knowledge-base-site-20)
  - [Customize site](https://docs.document360.com/docs/customize-site)
    - [KB site 2.0 migration](https://docs.document360.com/docs/kb-site-20-migration)
    - [Web Content Accessibility Guidelines (WCAG)](https://docs.document360.com/docs/web-content-accessibility-guidelines-wcag)
  - [Site header and footer](https://docs.document360.com/docs/site-header-and-footer)
    - [Header - Primary navigation](https://docs.document360.com/docs/header-primary-navigation)
    - [Header - Secondary navigation](https://docs.document360.com/docs/header-secondary-navigation)
    - [Footer](https://docs.document360.com/docs/footer-navigation)
    - [Custom footer](https://docs.document360.com/docs/custom-footer)
    - [RSS Feeds](https://docs.document360.com/docs/rss-feeds)
    - [Themes](https://docs.document360.com/docs/themes)
  - [Main pages](https://docs.document360.com/docs/main-pages)
    - [Hero section](https://docs.document360.com/docs/hero-section)
    - [Rich text blocks](https://docs.document360.com/docs/text-block)
    - [Multicolumn card section](https://docs.document360.com/docs/text-columns-block)
    - [Image with text block](https://docs.document360.com/docs/image-and-text)
    - [Custom code section](https://docs.document360.com/docs/html-block)
    - [Knowledge base categories block](https://docs.document360.com/docs/knowledge-base-categories)
    - [Widgets block](https://docs.document360.com/docs/widgets)
  - [Error pages](https://docs.document360.com/docs/error-pages)
    - [404 page](https://docs.document360.com/docs/404-page)
    - [Access denied page](https://docs.document360.com/docs/access-denied-page)
    - [Unauthorized page](https://docs.document360.com/docs/unauthorized-page)
    - [IP restriction page](https://docs.document360.com/docs/ip-restriction-page)
  - [Custom CSS & JavaScript](https://docs.document360.com/docs/custom-css-javascript)
    - [CSS Snippets](https://docs.document360.com/docs/css-snippets)
    - [Callout styles](https://docs.document360.com/docs/callout-styles)
    - [Body font style](https://docs.document360.com/docs/body-font-style)
    - [Image alignment](https://docs.document360.com/docs/image-alignment)
    - [Header font style](https://docs.document360.com/docs/header-font-style)
    - [Table style](https://docs.document360.com/docs/table-style)
  - [Article redirect rule](https://docs.document360.com/docs/article-redirect-rules)
  - [Article settings & SEO](https://docs.document360.com/docs/configuring-the-article-settings)
    - [Article header](https://docs.document360.com/docs/article-header)
    - [Site header-What's new](https://docs.document360.com/docs/document-header)
    - [Follow articles and categories](https://docs.document360.com/docs/follow-articles-and-categories)
    - [Search in Knowledge base site](https://docs.document360.com/docs/search-in-knowledge-base-site)
  - [Liking or disliking an article](https://docs.document360.com/docs/liking-or-disliking-an-article)
  - [Smart bar & Cookie consent](https://docs.document360.com/docs/smart-bar-cookie-consent)
    - [Smart bars](https://docs.document360.com/docs/smart-bar)
    - [Cookie consent](https://docs.document360.com/docs/cookie-consent)
  - Ticket deflectors
    - [Accessing the ticket deflectors in portal](https://docs.document360.com/docs/accessing-the-ticket-deflectors)
    - [Adding a new ticket deflector](https://docs.document360.com/docs/adding-a-new-ticket-deflector)
- [Integrations](https://docs.document360.com/docs/integrations)
  - [Integrations in Document360](https://docs.document360.com/docs/integrations-getting-started)
  - [Code inclusion and exclusion conditions](https://docs.document360.com/docs/advanced-insertion-rules-in-integration)
  - [Chat](https://docs.document360.com/docs/chat)
    - [LiveChat](https://docs.document360.com/docs/livechat)
    - [Olark](https://docs.document360.com/docs/olark)
    - [Freshchat](https://docs.document360.com/docs/freshchat)
    - [Crisp](https://docs.document360.com/docs/crisp)
    - [Chatra](https://docs.document360.com/docs/chatra)
    - [Doorbell](https://docs.document360.com/docs/door-bell)
    - [Gorgias](https://docs.document360.com/docs/gorgias)
    - [Belco](https://docs.document360.com/docs/belco)
    - [Sunshine Conversations](https://docs.document360.com/docs/sunshine)
    - [Kommunicate](https://docs.document360.com/docs/kommunicate)
  - [Analytics](https://docs.document360.com/docs/analytics-1)
    - [Google Analytics](https://docs.document360.com/docs/google-analytics-integration)
    - [Google Analytics (GA4)](https://docs.document360.com/docs/google-analytics-new)
    - [Google Tag Manager](https://docs.document360.com/docs/google-tag-manager)
    - [Heap](https://docs.document360.com/docs/heap)
    - [Segment](https://docs.document360.com/docs/segment-integration)
    - [Hotjar](https://docs.document360.com/docs/hotjar)
    - [Amplitude](https://docs.document360.com/docs/amplitude)
    - [FullStory](https://docs.document360.com/docs/fullstory)
    - [Mixpanel](https://docs.document360.com/docs/mixpanel)
  - [Marketing automation](https://docs.document360.com/docs/marketing-automation)
    - [VWO](https://docs.document360.com/docs/vwo)
    - [Freshmarketer](https://docs.document360.com/docs/freshmarketer)
    - [ZOHO PageSense](https://docs.document360.com/docs/zoho-page-sense)
    - [GoSquared](https://docs.document360.com/docs/gosquared)
  - [Commenting](https://docs.document360.com/docs/commenting)
    - [Commento](https://docs.document360.com/docs/commento)
    - [Disqus](https://docs.document360.com/docs/disqus)
- [Extensions](https://docs.document360.com/docs/extensions)
  - [Document360 Extensions - Getting started](https://docs.document360.com/docs/all-extensions)
  - [Helpdesk](https://docs.document360.com/docs/customer-support)
    - [Freshdesk](https://docs.document360.com/docs/freshdesk)
    - [Freshservice](https://docs.document360.com/docs/freshservice)
    - [Zendesk](https://docs.document360.com/docs/zendesk)
    - [Intercom](https://docs.document360.com/docs/intercom-integration)
    - [Salesforce](https://docs.document360.com/docs/salesforce-integration)
      - [Salesforce](https://docs.document360.com/docs/salesforce)
      - [Cases page](https://docs.document360.com/docs/cases-page)
  - [Team collaboration](https://docs.document360.com/docs/team-collaboration)
    - [Slack](https://docs.document360.com/docs/slack)
    - [Microsoft Teams](https://docs.document360.com/docs/microsoft-teams)
    - [Drift](https://docs.document360.com/docs/drift)
    - [Zapier](https://docs.document360.com/docs/zapier-integration)
      - [Zapier - Setup guide](https://docs.document360.com/docs/zapier-setup-guide)
      - [Use cases of Zapier](https://docs.document360.com/docs/use-cases-for-zap-templates)
        - [Integrating Google Docs with Document360](https://docs.document360.com/docs/google-docs-document360-integration)
        - [Integrating Google Sheets with Document360](https://docs.document360.com/docs/document360-with-google-sheets-integration)
        - [Integrating Document360 with Google Drive](https://docs.document360.com/docs/google-drive-document360)
        - [Integrating Trello with Document360](https://docs.document360.com/docs/document360-with-trello-integration)
        - [Integrating GitHub with Document360](https://docs.document360.com/docs/github-document360)
        - [Integrating Confluence Server with Document360](https://docs.document360.com/docs/confluence-document360)
        - [Integrating Zoho CRM with Document360](https://docs.document360.com/docs/zoho-crm-document360)
        - [Integrating Pipedrive with Document360](https://docs.document360.com/docs/pipedrive-document360)
        - [Integrating Hubspot with Document360](https://docs.document360.com/docs/hubspot-document360)
        - [Integrating Asana with Document360](https://docs.document360.com/docs/asana-document360)
        - [Integrating Monday.com with Document360](https://docs.document360.com/docs/mondaycom-document360)
        - [Integrating Typeform with Document360](https://docs.document360.com/docs/typeform-document360)
        - [Integrating Gmail with Document360](https://docs.document360.com/docs/document360-gmail)
        - [Integrating Mailchimp with Document360](https://docs.document360.com/docs/document360-mailchimp)
    - [Make](https://docs.document360.com/docs/make-1)
      - [Make - Setup guide](https://docs.document360.com/docs/make-setup-guide)
      - [Use cases for Make Scenarios](https://docs.document360.com/docs/use-cases-for-make-scenarios)
        - [Integrating Asana with Document360](https://docs.document360.com/docs/asana-and-document360-integration)
        - [Integrating Monday.com with Document360](https://docs.document360.com/docs/monday-document360-integration)
        - [Integrating Typeform with Document360](https://docs.document360.com/docs/typeform-and-document360-integration)
        - [Integrating Google Docs with Document360](https://docs.document360.com/docs/google-docs-and-document360-integration)
        - [Integrating Jira with Document360](https://docs.document360.com/docs/jira-and-document360-integration)
  - Code repositories
    - [GitHub](https://docs.document360.com/docs/github-extension)
  - [Translation and browser](https://docs.document360.com/docs/translation)
    - [Chrome](https://docs.document360.com/docs/chrome-extension)
    - [Crowdin](https://docs.document360.com/docs/crowdin)
    - [Phrase](https://docs.document360.com/docs/phrase)
- [Portal management](https://docs.document360.com/docs/portal-management)
  - [General project settings](https://docs.document360.com/docs/general-project-settings)
  - [Team auditing](https://docs.document360.com/docs/team-auditing)
  - [Localization & Workspace](https://docs.document360.com/docs/localization-workspace)
    - [Localization](https://docs.document360.com/docs/localization)
      - [Localization - Getting started](https://docs.document360.com/docs/localization-getting-started)
      - [Setting up a Multi-lingual knowledge base](https://docs.document360.com/docs/setting-up-a-multi-lingual-knowledge-base)
      - [Localization variables](https://docs.document360.com/docs/localization-variables)
      - [AI machine translation](https://docs.document360.com/docs/ai-machine-translation-1)
    - [Workspaces](https://docs.document360.com/docs/workspaces)
  - [Backup and restore](https://docs.document360.com/docs/backup-restore)
  - [Notifications](https://docs.document360.com/docs/notifications)
    - [Webhook notification channel](https://docs.document360.com/docs/webhook-notification-channel)
    - [Slack notification channel](https://docs.document360.com/docs/slack-notification-channel)
    - [Microsoft Teams notification channel](https://docs.document360.com/docs/microsoft-teams-notification-channel)
    - [SMTP notification channel](https://docs.document360.com/docs/smtp-email-notification-channel)
    - [Notification mapping](https://docs.document360.com/docs/notification-mapping)
    - [Notification history](https://docs.document360.com/docs/notification-history)
    - [Email domain](https://docs.document360.com/docs/send-notifications-from-custom-email-domain)
  - [API tokens](https://docs.document360.com/docs/api-tokens)
  - [External API Tools](https://docs.document360.com/docs/external-api-tools)
    - [How to use Postman?](https://docs.document360.com/docs/how-to-use-postman)
    - [How to use Swagger?](https://docs.document360.com/docs/how-to-use-swagger)
  - [Portal search](https://docs.document360.com/docs/full-portal-search)
    - [Article-portal search](https://docs.document360.com/docs/article-full-portal-search)
    - [Drive-portal search](https://docs.document360.com/docs/drive-full-portal-search)
    - [Users & groups-portal search](https://docs.document360.com/docs/users-groups-full-portal-search)
    - [Tags-portal search](https://docs.document360.com/docs/tags-full-portal-search)
    - [Settings-portal search](https://docs.document360.com/docs/settings-full-portal-search)
- [Domain management](https://docs.document360.com/docs/domain-management)
  - [Custom domain mapping](https://docs.document360.com/docs/custom-domain-mapping)
  - [Hosting Document360 on a sub-directory](https://docs.document360.com/docs/document360-on-a-sub-folder)
  - [Nginx server - Subfolder hosting](https://docs.document360.com/docs/nginx-server)
  - [ASP.NET Core server](https://docs.document360.com/docs/aspnet-core-server)
  - [Microsoft - IIS server](https://docs.document360.com/docs/microsoft-iis-server)
  - [Apache HTTP server](https://docs.document360.com/docs/apache-http-server)
- [User management](https://docs.document360.com/docs/user-management)
  - [Managing team accounts](https://docs.document360.com/docs/managing-team-account)
  - [Managing team account groups](https://docs.document360.com/docs/team-account-groups-overview-page)
  - [Managing readers](https://docs.document360.com/docs/reader-accounts)
  - [Managing reader groups](https://docs.document360.com/docs/managing-reader-groups)
  - [Readers self registration](https://docs.document360.com/docs/reader-self-registration)
  - [Managing reviewer accounts](https://docs.document360.com/docs/managing-reviewer-accounts)
  - [Account locked](https://docs.document360.com/docs/account-locked)
- [Access management](https://docs.document360.com/docs/access-management)
  - [Roles and permissions](https://docs.document360.com/docs/roles)
  - [Content access](https://docs.document360.com/docs/content-role-and-access)
  - [Block inheritance](https://docs.document360.com/docs/block-inheritance)
  - [Site access](https://docs.document360.com/docs/site-access)
  - [IP restriction](https://docs.document360.com/docs/ip-restriction)
- [Single Sign-On (SSO)](https://docs.document360.com/docs/single-sign-on-sso)
  - [Login using SSO - Knowledge base portal](https://docs.document360.com/docs/login-using-sso-knowledge-base-portal)
  - [Login using SSO - Knowledge base site](https://docs.document360.com/docs/login-using-sso-knowledge-base-site)
  - [Inviting or Adding SSO users](https://docs.document360.com/docs/inviting-or-adding-sso-users)
  - [Mapping an existing SSO configuration to other projects](https://docs.document360.com/docs/mapping-an-existing-sso-configuration-to-other-projects)
  - [Disable Document360 login page](https://docs.document360.com/docs/disable-document360-login-page)
  - [Auto assign reader group](https://docs.document360.com/docs/auto-assign-reader-group)
  - [Convert to SSO account](https://docs.document360.com/docs/convert-to-sso-account)
  - [Sign out idle SSO team account](https://docs.document360.com/docs/team-account-idle-timeout)
  - [SAML](https://docs.document360.com/docs/saml)
    - [SAML SSO with Okta](https://docs.document360.com/docs/saml-sso-with-okta)
    - [SAML SSO with Entra](https://docs.document360.com/docs/saml-sso-with-entra)
    - [SAML SSO with Google](https://docs.document360.com/docs/google-sso-saml-configuration)
    - [SAML SSO with OneLogin](https://docs.document360.com/docs/saml-sso-with-onelogin)
    - [SAML SSO with ADFS](https://docs.document360.com/docs/saml-sso-with-adfs)
    - [SAML SSO with other configurations](https://docs.document360.com/docs/saml-sso-with-other-configurations)
    - [Identity Provider (IdP) initiated sign in](https://docs.document360.com/docs/idp-initiated-login)
    - [Removing a configured SAML SSO](https://docs.document360.com/docs/removing-a-configured-saml-sso)
  - [OpenID](https://docs.document360.com/docs/openid)
    - [Okta with OpenID SSO](https://docs.document360.com/docs/okta-with-openid-sso)
    - [Auth0 with OpenID SSO](https://docs.document360.com/docs/auth0-with-openid-sso)
    - [ADFS with OpenID SSO](https://docs.document360.com/docs/adfs-with-openid-sso)
    - [Other configurations with OpenID SSO](https://docs.document360.com/docs/other-configurations-with-openid-sso)
    - [Removing a configured OpenID SSO](https://docs.document360.com/docs/removing-a-configured-openid-sso)
  - [JWT](https://docs.document360.com/docs/jwt)
    - [Setting up JWT SSO](https://docs.document360.com/docs/configuring-the-jwt-sso)
    - [JWT reader groups](https://docs.document360.com/docs/jwt-reader-groups)
- [Customization](https://docs.document360.com/docs/customization-editor)
  - [How to enlarge the pdf preview in the article?](https://docs.document360.com/docs/how-to-enlarge-the-pdf-preview-in-the-article)
  - [How to change the color of the hyperlinks in Dark mode?](https://docs.document360.com/docs/how-to-change-the-color-of-the-hyperlinks-in-dark-mode)
  - [How to change the highlighted search result color in articles?](https://docs.document360.com/docs/how-to-change-the-highlighted-search-result-color-in-articles)
  - [How to hide the project's workspace dropdown in the Knowledge base site?](https://docs.document360.com/docs/how-to-hide-the-project-versions-dropdown-in-the-knowledge-base-site)
  - [How to add a vertical scrollbar to the code blocks?](https://docs.document360.com/docs/how-to-add-a-vertical-scrollbar-to-the-code-blocks)
  - [How to set the default height and width of the embedded PDF?](https://docs.document360.com/docs/how-to-set-the-default-height-and-width-of-the-embedded-pdf)
  - [How to make the table border bold in knowledge base?](https://docs.document360.com/docs/how-to-make-the-table-border-bold-in-knowledge-base)
  - [How to vertically align table contents at the top in the Knowledge base?](https://docs.document360.com/docs/how-to-vertically-align-table-contents-at-the-top-in-the-knowledge-base)
  - [How to restrict the readers from copying the content?](https://docs.document360.com/docs/how-to-restrict-the-readers-from-copying-the-content)
  - [How to keep dark mode for the Knowledge base site by default?](https://docs.document360.com/docs/how-to-keep-dark-mode-for-the-knowledge-base-site-by-default)
  - [How to center align the text in Markdown?](https://docs.document360.com/docs/how-to-center-align-the-text-in-markdown)
  - [How to change the color of the text in Markdown?](https://docs.document360.com/docs/how-to-change-the-color-of-the-text-in-markdown)
  - [How to change the language name text in code blocks?](https://docs.document360.com/docs/how-to-change-the-language-name-text-in-code-blocks)
  - [How to change the callouts color in dark mode?](https://docs.document360.com/docs/how-to-change-the-callouts-color-in-dark-mode)
  - [How to center align the heading in the articles?](https://docs.document360.com/docs/how-to-center-align-the-heading-in-the-articles)
  - [How to change the color of the table header?](https://docs.document360.com/docs/how-to-change-the-color-of-the-table-header)
  - [How to add accordion in Markdown?](https://docs.document360.com/docs/how-to-add-accordion-in-markdown)
  - [How to add extra space in Markdown?](https://docs.document360.com/docs/how-to-add-extra-space-in-markdown)
  - [How to align the image in Markdown?](https://docs.document360.com/docs/how-to-align-the-image-in-markdown)
  - [How to add a background image for a text content?](https://docs.document360.com/docs/how-to-add-a-background-image-for-a-text-content)
  - [How to change the color of the table of contents?](https://docs.document360.com/docs/how-to-change-the-color-of-the-table-of-contents)
  - [How to sort the contents of a table?](https://docs.document360.com/docs/how-to-sort-the-contents-of-a-table)
  - [How to customize the hyperlink size?](https://docs.document360.com/docs/how-to-customize-the-hyperlink)
  - [How to make all links open in new tab?](https://docs.document360.com/docs/how-to-make-all-links-open-in-new-tab)
  - [How to set a default featured image in knowledge base?](https://docs.document360.com/docs/how-to-set-a-default-featured-image-in-knowledge-base)
  - [How to add shadows to an image in Markdown?](https://docs.document360.com/docs/how-to-add-shadows-to-an-image-in-markdown)
  - [How to add borders to an image in Markdown?](https://docs.document360.com/docs/how-to-add-borders-to-an-image-in-markdown)
  - [How to embed YouTube Shorts?](https://docs.document360.com/docs/embed-youtube-shorts)
  - [How to embed a Loom video?](https://docs.document360.com/docs/how-to-embed-loom-video)
  - [How to embed an Excel file?](https://docs.document360.com/docs/how-to-embed-an-excel-file)
  - [How to change the color of Feedback buttons?](https://docs.document360.com/docs/how-to-change-the-color-of-feedback-buttons)
  - [How to hide footer in mobile view?](https://docs.document360.com/docs/how-to-hide-footer-in-mobile-view)
  - [How to change the hover color of the header options?](https://docs.document360.com/docs/how-to-change-the-hover-color-of-the-header-options)
  - [How to move the related articles above the feedback section?](https://docs.document360.com/docs/how-to-move-the-related-articles-above-the-feedback-section)
  - [How to hide the change password option for readers?](https://docs.document360.com/docs/how-to-hide-the-change-password-option-for-readers)
  - [How to configure a custom header font in the knowledge base?](https://docs.document360.com/docs/how-to-configure-a-custom-header-font-in-the-knowledge-base)
  - [How to hide the category manager?](https://docs.document360.com/docs/how-to-hide-the-category-manager)
  - [How to configure a custom font in the knowledge base?](https://docs.document360.com/docs/how-to-configure-a-custom-font-in-the-knowledge-base)
  - [How to hide the left navigation bar in the knowledge base site?](https://docs.document360.com/docs/how-to-hide-the-left-navigation-bar-in-knowledge-base-site)
- [Billing & Subscription](https://docs.document360.com/docs/billing)
  - [Plans and pricing](https://docs.document360.com/docs/plans-and-pricing)
  - [Upgrading your subscription plan](https://docs.document360.com/docs/upgrading-your-plan)
  - [Downgrading your subscription plan](https://docs.document360.com/docs/downgrading-your-plan)
  - [Purchasing add-ons](https://docs.document360.com/docs/add-ons)
  - [Upgrading from trial version](https://docs.document360.com/docs/upgrading-from-trial-version)
  - [Changing payment information](https://docs.document360.com/docs/changing-payment-information)
- [Release notes](https://docs.document360.com/docs/release-notes)
  - [2025](https://docs.document360.com/docs/2025)
    - [February 2025 - 11.1.2](https://docs.document360.com/docs/february-2025-1112)
    - [January 2025 - 11.01.1](https://docs.document360.com/docs/january-2025-1111)
  - [2024](https://docs.document360.com/docs/2024)
    - [December 2024 - 10.12.1](https://docs.document360.com/docs/december-2024-10121)
    - [November 2024 - 10.11.1](https://docs.document360.com/docs/november-2024-10111)
    - [October 2024 - 10.10.1](https://docs.document360.com/docs/october-2024-10101)
    - [September 2024 - 10.9.1](https://docs.document360.com/docs/september-2024-1091)
    - [September 2024 - 10.8.2](https://docs.document360.com/docs/september-2024-1082)
    - [August 2024 - 10.8.1](https://docs.document360.com/docs/august-2024-1081)
    - [July 2024 - 10.7.1](https://docs.document360.com/docs/july-2024-1071)
    - [July 2024 - 10.6.2](https://docs.document360.com/docs/july-2024-1062)
    - [June 2024 - 10.6.1](https://docs.document360.com/docs/june-2024-1061)
    - [June 2024 - 10.5.2](https://docs.document360.com/docs/june-2024-1052)
    - [May 2024 - 10.5.1](https://docs.document360.com/docs/may-2024-1051)
    - [May 2024 - 10.4.2](https://docs.document360.com/docs/may-2024-1042)
    - [April 2024 - 10.4.1](https://docs.document360.com/docs/1041-release-note)
    - [April 2024 - Minor release](https://docs.document360.com/docs/april-2024-minor-release)
    - [March 2024](https://docs.document360.com/docs/march-2024)
    - [February 2024](https://docs.document360.com/docs/february-2024)
    - [January 2024](https://docs.document360.com/docs/january-2024)
  - [2023](https://docs.document360.com/docs/2023)
    - [December 2023](https://docs.document360.com/docs/december-2023)
    - [November 2023](https://docs.document360.com/docs/november-2023)
    - [October 2023](https://docs.document360.com/docs/october-2023)
    - [August 2023](https://docs.document360.com/docs/august-3)
    - [July 2023](https://docs.document360.com/docs/july-2)
    - [June 2023](https://docs.document360.com/docs/june-3)
    - [May 2023](https://docs.document360.com/docs/may-1)
    - [April 2023](https://docs.document360.com/docs/april-3)
    - [March 2023](https://docs.document360.com/docs/march-4)
    - [February 2023](https://docs.document360.com/docs/february-3)
    - [January 2023](https://docs.document360.com/docs/january-2)
  - [2022](https://docs.document360.com/docs/2022)
    - [December 2022](https://docs.document360.com/docs/december-2022-release-note)
    - [November 2022](https://docs.document360.com/docs/november-2022-release-note)
    - [October 2022](https://docs.document360.com/docs/october-2022-release-note)
    - [September 2022](https://docs.document360.com/docs/september-2022-release-note)
    - [August 2022](https://docs.document360.com/docs/august-2022-release-note)
    - [July 2022](https://docs.document360.com/docs/july-2022-release-note)
    - [June 2022](https://docs.document360.com/docs/june-2022-release-notes)
    - [May 2022](https://docs.document360.com/docs/may-2022-release-note)
    - [April 2022](https://docs.document360.com/docs/april-2022-release-note)
    - [March 2022](https://docs.document360.com/docs/march-2022-release-note)
    - [February 2022](https://docs.document360.com/docs/february-2022-release-note)
    - [January 2022](https://docs.document360.com/docs/january-2022-release-note)
  - [2021](https://docs.document360.com/docs/2021)
    - [December 2021](https://docs.document360.com/docs/december-2021-release-note)
    - [November 2021](https://docs.document360.com/docs/november-2021-release-note)
    - [October 2021](https://docs.document360.com/docs/october-2021-release-note)
    - [September 2021](https://docs.document360.com/docs/september-2021-release-note)
    - [August 2021](https://docs.document360.com/docs/august-2021-release-notes)
    - [July 2021](https://docs.document360.com/docs/july-2021-release-note)
    - [June 2021](https://docs.document360.com/docs/june-2021-release-note)
    - [May 2021](https://docs.document360.com/docs/may-2021-release-note)
    - [April 2021](https://docs.document360.com/docs/april-2021-release-note)
    - [March 2021](https://docs.document360.com/docs/march-2021-release-note)
    - [February 2021](https://docs.document360.com/docs/february-2021-release-note)
    - [January 2021](https://docs.document360.com/docs/january-2021-release-note)
  - [2020](https://docs.document360.com/docs/2020)
    - [November 2020](https://docs.document360.com/docs/november-2020-release-note)
    - [October 2020](https://docs.document360.com/docs/october-2020-release-note)
    - [August 2020](https://docs.document360.com/docs/august-2020-release-note)
    - [June 2020](https://docs.document360.com/docs/june-2020-release-note)
    - [May 2020](https://docs.document360.com/docs/may-2020-release-note)
    - [April 2020](https://docs.document360.com/docs/april-2020-release-note)
    - [March 2020](https://docs.document360.com/docs/march-2020-release-note)
    - [February 2020](https://docs.document360.com/docs/february-2020-release-note)
    - [January 2020](https://docs.document360.com/docs/january-2020)
  - [2019](https://docs.document360.com/docs/2019)
    - [December 2019](https://docs.document360.com/docs/december)
    - [November 2019](https://docs.document360.com/docs/november)
    - [October 2019](https://docs.document360.com/docs/october)
    - [September 2019](https://docs.document360.com/docs/september-2019)
    - [August 2019](https://docs.document360.com/docs/august)
    - [July 2019](https://docs.document360.com/docs/july)
    - [June 2019](https://docs.document360.com/docs/june)
    - [May 2019](https://docs.document360.com/docs/may-2019)
    - [April 2019](https://docs.document360.com/docs/april-2019)
    - [March 2019](https://docs.document360.com/docs/march)
    - [February 2019](https://docs.document360.com/docs/february)
    - [January 2019](https://docs.document360.com/docs/january-2019)
- [Support](https://docs.document360.com/docs/support)